@@ -47,7 +47,7 @@ from luma.lcd.segment_mapper import dot_muncher
 from luma.core.virtual import character
 from luma.core.bitmap_font import embedded_fonts
 
-__all__ = ["pcd8544", "st7735", "ht1621", "uc1701x", "st7567", "ili9341", "hd44780"]
+__all__ = ["pcd8544", "st7735", "ht1621", "uc1701x", "st7567", "ili9341", "ili9486", "hd44780"]
 
 
 class GPIOBacklight:
@@ -63,6 +63,7 @@ class GPIOBacklight:
 
     .. versionadded:: 2.3.0
     """
+
     def __init__(self, gpio, pin=18, active_low=True):
         self._gpio = gpio
         self._pin = pin
@@ -113,6 +114,7 @@ class I2CBackpackBacklight:
 
     .. versionadded:: 2.5.0
     """
+
     def __init__(self, serial_interface, pin=None):
         self._serial_interface = serial_interface
 
@@ -150,6 +152,7 @@ class PWMBacklight:
 
     .. versionadded:: 2.3.0
     """
+
     def __init__(self, gpio, pin=18, frequency=362):
         self._gpio = gpio
 
@@ -200,6 +203,7 @@ class backlit_device(device):
 
     .. versionadded:: 2.0.0
     """
+
     def __init__(self, const=None, serial_interface=None, gpio=None, gpio_LIGHT=18, active_low=True, pwm_frequency=None, backpack_pin=None, **kwargs):
         super(backlit_device, self).__init__(const, serial_interface)
 
@@ -246,6 +250,7 @@ class pcd8544(backlit_device):
         represents 270° rotation.
     :type rotate: int
     """
+
     def __init__(self, serial_interface=None, rotate=0, **kwargs):
         super(pcd8544, self).__init__(luma.lcd.const.pcd8544, serial_interface, **kwargs)
         self.capabilities(84, 48, rotate)
@@ -305,6 +310,7 @@ class st7567(backlit_device):
 
     .. versionadded:: 1.1.0
     """
+
     def __init__(self, serial_interface=None, rotate=0, **kwargs):
         super(st7567, self).__init__(luma.lcd.const.st7567, serial_interface, **kwargs)
         self.capabilities(128, 64, rotate)
@@ -378,8 +384,10 @@ class __framebuffer_mixin(object):
         also be removed at that point.
     """
 
-    def init_framebuffer(self, framebuffer):
-        if isinstance(framebuffer, str):
+    def init_framebuffer(self, framebuffer, default_num_segments):
+        if framebuffer is None:
+            self.framebuffer = diff_to_previous(num_segments=default_num_segments)
+        elif isinstance(framebuffer, str):
             import warnings
             warnings.warn(
                 "Specifying framebuffer as a string is now deprecated; Supply an instance of class full_frame() or diff_to_previous() instead",
@@ -425,12 +433,12 @@ class st7735(backlit_device, __framebuffer_mixin):
 
     .. versionadded:: 0.3.0
     """
+
     def __init__(self, serial_interface=None, width=160, height=128, rotate=0,
-                 framebuffer=diff_to_previous(num_segments=16), h_offset=0, v_offset=0,
-                 bgr=False, inverse=False, **kwargs):
+                 framebuffer=None, h_offset=0, v_offset=0, bgr=False, inverse=False, **kwargs):
         super(st7735, self).__init__(luma.lcd.const.st7735, serial_interface, **kwargs)
         self.capabilities(width, height, rotate, mode="RGB")
-        self.init_framebuffer(framebuffer)
+        self.init_framebuffer(framebuffer, 16)
 
         if h_offset != 0 or v_offset != 0:
             def offset(bbox):
@@ -552,12 +560,12 @@ class ili9341(backlit_device, __framebuffer_mixin):
 
     .. versionadded:: 2.2.0
     """
+
     def __init__(self, serial_interface=None, width=320, height=240, rotate=0,
-                 framebuffer=diff_to_previous(num_segments=25), h_offset=0, v_offset=0,
-                 bgr=False, **kwargs):
+                 framebuffer=None, h_offset=0, v_offset=0, bgr=False, **kwargs):
         super(ili9341, self).__init__(luma.lcd.const.ili9341, serial_interface, **kwargs)
         self.capabilities(width, height, rotate, mode="RGB")
-        self.init_framebuffer(framebuffer)
+        self.init_framebuffer(framebuffer, 25)
 
         if h_offset != 0 or v_offset != 0:
             def offset(bbox):
@@ -649,6 +657,163 @@ class ili9341(backlit_device, __framebuffer_mixin):
             self._serial_interface.data(list(args))
 
 
+class ili9486(backlit_device, __framebuffer_mixin):
+    """
+    Serial interface to a 262k color (6-6-6 RGB) ILI9486 LCD display.
+
+    On creation, an initialization sequence is pumped to the display to properly
+    configure it. Further control commands can then be called to affect the
+    brightness (if implemented) and other settings.
+
+    Note that the ILI9486 display used for development -- a Waveshare
+    3.5-inch IPS LCD(B) -- used a portrait orientation.  Images were
+    rendered correctly only when specifying that height was 480 pixels
+    and the width was 320.
+
+    :param serial_interface: the serial interface (usually a
+        :py:class:`luma.core.interface.serial.spi` instance) to delegate sending
+        data and commands through.
+    :param width: The number of pixels laid out horizontally.
+    :type width: int
+    :param height: The number of pixels laid out vertically.
+    :type height: int
+    :param rotate: An integer value of 0 (default), 1, 2 or 3 only, where 0 is
+        no rotation, 1 is rotate 90° clockwise, 2 is 180° rotation and 3
+        represents 270° rotation.
+    :type rotate: int
+    :param framebuffer: Framebuffering strategy, currently instances of
+        ``diff_to_previous()`` or ``full_frame()`` are only supported.
+    :type framebuffer: luma.core.framebuffer.framebuffer
+    :param bgr: Set to ``True`` if device pixels are BGR order (rather than RGB).
+    :type bgr: bool
+    :param h_offset: Horizontal offset (in pixels) of screen to device memory
+        (default: 0).
+    :type h_offset: int
+    :param v_offset: Vertical offset (in pixels) of screen to device memory
+        (default: 0).
+    :type v_offset: int
+
+    .. versionadded:: 2.8.0
+    """
+
+    def __init__(self, serial_interface=None, width=320, height=480, rotate=0,
+                 framebuffer=None, h_offset=0, v_offset=0, bgr=False, **kwargs):
+        super(ili9486, self).__init__(luma.lcd.const.ili9486, serial_interface, **kwargs)
+        self.capabilities(width, height, rotate, mode="RGB")
+        self.init_framebuffer(framebuffer, 25)
+
+        if h_offset != 0 or v_offset != 0:
+            def offset(bbox):
+                left, top, right, bottom = bbox
+                return (left + h_offset, top + v_offset, right + h_offset, bottom + v_offset)
+            self.apply_offsets = offset
+        else:
+            self.apply_offsets = lambda bbox: bbox
+
+        # Supported modes
+        supported = (width, height) in [(320, 480)]  # full
+        if not supported:
+            raise luma.core.error.DeviceDisplayModeError(
+                "Unsupported display mode: {0} x {1}".format(width, height))
+
+        # RGB or BGR order
+        order = 0x00 if bgr else 0x08
+
+        # Initialization sequence, adapted from MIT Licensed
+        #
+        #   `https://github.com/juj/fbcp-ili9341/blob/master/ili9486.cpp`
+        #
+        # and peer files.  The sequence targets the ILI9486-based
+        # Waveshare "Wavepear" 3.5 inch 320x480 LCD (B)
+        # implementation.  Per comments in the above file and issue
+        # discussion for juj/fbcp-ili9341, the Waveshare
+        # implementation makes use of 16-bit shift register for the
+        # SPI interface, leaving the ILI9486 itself in a parallel
+        # mode.
+        #
+        # The result of that implementation is that registers
+        # effectively become 16-bit quantities.  The sequence below
+        # (and in the display() function) thus ends up padding
+        # commands and subsequent values.  It doesn't seem to have
+        # affected pixel transfers, though.
+        #
+        # A different ILI9486 implementation may NOT need the padding
+        # zeros.  The juj/fbcp-ili9341 code handles that possibility
+        # via a DISPLAY_SPI_BUS_IS_16BITS_WIDE ifdef.
+
+        self.command(0xb0, 0x00, 0x00)                      # Interface Mode Control
+        self.command(0x11)                                  # sleep out
+        sleep(0.150)
+        self.command(0x3a, 0x00, 0x66)                      # Interface Pixel Format 6-6-6
+        self.command(0x21)                                  # Display inversion ON for LCD(B)
+        self.command(0xc0, 0x00, 0x09, 0x00, 0x09)          # Power Control 1
+        self.command(0xc1, 0x00, 0x41, 0x00, 0x00)          # Power Control 2
+        self.command(0xc2, 0x00, 0x33)                      # Power Control 3 (for normal mode)
+        self.command(0xc5, 0x00, 0x00, 0x00, 0x36)          # VCOM control
+
+        self.command(0x36, 0x00, 0x00 | order)              # Memory Access control (MAD), rotations and color order
+        # self.command(0xb1, 0x00, 0xb0, 0x00, 0xe0)          # Frame Rate Control (needed?)
+
+        self.command(0xb6, 0x00, 0x00, 0x00, 0x42, 0x00, 59)        # Display Function Control
+
+        # Initial trials didn't seem to need Positive, Negative, or
+        # Digital Gamma Control settings.
+
+        self.command(0x13)                                  # Normal mode ON
+        self.command(0x34)                                  # Tearing effect line oFF
+        self.command(0x38)                                  # Idle mode OFF
+
+        self.command(0x11)                                  # sleep out
+        sleep(0.150)
+        self.clear()
+        self.show()
+
+    def display(self, image):
+        """
+        Renders a 24-bit RGB image to the ILI9486 LCD display. The 8-bit RGB
+        values are passed directly to the devices internal storage, but only
+        the 6 most-significant bits are used by the display.
+
+        :param image: The image to render.
+        :type image: PIL.Image.Image
+        """
+        assert(image.mode == self.mode)
+        assert(image.size == self.size)
+
+        image = self.preprocess(image)
+
+        for image, bounding_box in self.framebuffer.redraw(image):
+            # Transposing the display shifts the dimension measurements
+            top, left, bottom, right = self.apply_offsets(bounding_box)
+
+            # Per earlier comments, Waveshare's display needs padding
+            # for commands.
+            self.command(0x2a, 0, top >> 8, 0, top & 0xff, 0, (bottom - 1) >> 8, 0, (bottom - 1) & 0xff)     # Set row addr
+            self.command(0x2b, 0, left >> 8, 0, left & 0xff, 0, (right - 1) >> 8, 0, (right - 1) & 0xff)     # Set column addr
+            self.command(0x2c)                                                                   # Memory write
+
+            self.data(image.tobytes())
+
+    def contrast(self, level):
+        """
+        NOT SUPPORTED
+
+        :param level: Desired contrast level in the range of 0-255.
+        :type level: int
+        """
+        assert(0 <= level <= 255)
+
+    def command(self, cmd, *args):
+        """
+        Sends a command and an (optional) sequence of arguments through to the
+        delegated serial interface. Note that the arguments are passed through
+        as data.
+        """
+        self._serial_interface.command(cmd)
+        if len(args) > 0:
+            self._serial_interface.data(list(args))
+
+
 @rpi_gpio
 class ht1621(backlit_device):
     """
@@ -675,6 +840,7 @@ class ht1621(backlit_device):
 
     .. versionadded:: 0.4.0
     """
+
     def __init__(self, gpio=None, width=6, rotate=0, WR=11, DAT=10, CS=8, **kwargs):
         if 'serial_interface' in kwargs:
             del kwargs['serial_interface']
@@ -774,6 +940,7 @@ class uc1701x(backlit_device):
 
     .. versionadded:: 0.5.0
     """
+
     def __init__(self, serial_interface=None, rotate=0, **kwargs):
         super(uc1701x, self).__init__(luma.lcd.const.uc1701x, serial_interface, **kwargs)
         self.capabilities(128, 64, rotate)
@@ -899,9 +1066,9 @@ class hd44780(backlit_device, parallel_device, character, __framebuffer_mixin):
 
     .. versionadded:: 2.5.0
     """
+
     def __init__(self, serial_interface=None, width=16, height=2, undefined='_',
-                 selected_font=0, exec_time=0.000001,
-                 framebuffer=diff_to_previous(num_segments=1), **kwargs):
+                 selected_font=0, exec_time=0.000001, framebuffer=None, **kwargs):
         super(hd44780, self).__init__(luma.lcd.const.hd44780, serial_interface,
         exec_time=exec_time, **kwargs)
 
@@ -910,7 +1077,7 @@ class hd44780(backlit_device, parallel_device, character, __framebuffer_mixin):
         self._exec_time = exec_time
 
         self.capabilities(width * 5, height * 8, 0)
-        self.init_framebuffer(framebuffer)
+        self.init_framebuffer(framebuffer, 1)
 
         # Currently only support 5x8 fonts for the hd44780
         self.font = embedded_fonts(self._const.FONTDATA,
